/*
 * Copyright 2007 Etienne Studer
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nu.studer.idea.notifier;

import java.io.InputStream;
import java.io.StringWriter;
import java.net.HttpURLConnection;
import java.net.URL;
import java.net.URLConnection;
import java.util.Iterator;

import org.jetbrains.annotations.NonNls;
import org.jetbrains.annotations.NotNull;
import com.intellij.openapi.util.JDOMUtil;

import org.jdom.Document;
import org.jdom.Element;
import org.jdom.filter.ElementFilter;

/**
 * This class tests requesting the plugin repository state.
 *
 * @author <a href="mailto:intellij@studer.nu">Etienne Studer</a>, Nov 12, 2006
 */
public class TestingUpdateNotifier {
    @NonNls
    private static final String IDEA_PLUGIN_ELEMENT = "idea-plugin";

    public static void main(@NotNull String[] inArgs) {
        Runnable runnable = new Runnable() {
            public void run() {
                queryRepository();
            }
        };

        new Thread(runnable).start();
        new Thread(runnable).start();
        new Thread(runnable).start();
        new Thread(runnable).start();
    }

    private static void queryRepository() {
        try {
            @NonNls URL url = new URL("http://plugins.intellij.net/plugins/list/?build=5784");
            URLConnection connection = url.openConnection();

            InputStream is = connection.getInputStream();
            Document doc = JDOMUtil.loadDocument(is);
            String content = JDOMUtil.writeDocument(doc, "\n");
            System.err.println(content);

            Iterator pluginsIterator = doc.getRootElement().getDescendants(new ElementFilter(IDEA_PLUGIN_ELEMENT));
            while (pluginsIterator.hasNext()) {
                Element ideaPluginElement = (Element) pluginsIterator.next();
                StringWriter stringWriter = new StringWriter();
                JDOMUtil.writeElement(ideaPluginElement, stringWriter, "\n");
                System.out.println(stringWriter.toString());
            }

            if (connection instanceof HttpURLConnection) {
                HttpURLConnection urlConnection = (HttpURLConnection) connection;
                urlConnection.disconnect();
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }
}
